@@ -7,7 +7,7 @@ use Carp;
 use Woothee::Util qw/update_map update_category update_version update_os/;
 use Woothee::DataSet qw/dataset/;
 
-our $VERSION = "0.2.1";
+our $VERSION = "0.2.2";
 
 sub challenge_playstation {
     my ($ua, $result) = @_;
@@ -67,3 +67,26 @@ sub challenge_digitaltv {
 }
 
 1;
+
+__END__
+
+=head1 NAME
+
+Woothee::Appliance - part of Woothee
+
+For Woothee, see https://github.com/tagomoris/woothee
+
+=head1 DESCRIPTION
+
+This module doesn't have any public interfaces. To parse user-agent strings, see module 'Woothee'.
+
+=head1 AUTHOR
+
+TAGOMORI Satoshi E<lt>tagomoris {at} gmail.comE<gt>
+
+=head1 LICENSE
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=cut
