@@ -6,7 +6,7 @@ use Carp;
 
 use Woothee::DataSet;
 
-our $VERSION = "0.2.1";
+our $VERSION = "0.2.2";
 
 our (@ISA, @EXPORT_OK);
 BEGIN {
@@ -41,3 +41,26 @@ sub update_os {
 }
 
 1;
+
+__END__
+
+=head1 NAME
+
+Woothee::Util - part of Woothee
+
+For Woothee, see https://github.com/tagomoris/woothee
+
+=head1 DESCRIPTION
+
+This module doesn't have any public interfaces. To parse user-agent strings, see module 'Woothee'.
+
+=head1 AUTHOR
+
+TAGOMORI Satoshi E<lt>tagomoris {at} gmail.comE<gt>
+
+=head1 LICENSE
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=cut
